@@ -806,6 +806,32 @@ class CustomUnitTest(TestCase):
                                       code='my_unit').count(),
             1)
 
+    def test_creation_with_dash(self):
+        """
+        Test creation of a CustomUnit with - in code, symbol and alias
+        """
+        cu = CustomUnit.objects.create(
+            user=self.user,
+            key=self.key,
+            unit_system='SI',
+            code='my-unit',
+            name='My Unit',
+            relation="1.5 meter",
+            symbol="m-yu",
+            alias="m-yu")
+        self.assertEqual(cu.user, self.user)
+        self.assertEqual(cu.key, self.key)
+        self.assertEqual(cu.unit_system, 'SI')
+        self.assertEqual(cu.code, 'my_unit')
+        self.assertEqual(cu.name, 'My Unit')
+        self.assertEqual(cu.relation, '1.5 meter')
+        self.assertEqual(cu.symbol, 'm_yu')
+        self.assertEqual(cu.alias, 'm_yu')
+        self.assertEqual(
+            CustomUnit.objects.filter(user=self.user, key=self.key, unit_system='SI',
+                                      code='my_unit').count(),
+            1)
+
     def test_invalid_creation_params(self):
         """
         Test invalid creation params
@@ -1396,31 +1422,31 @@ class OperandTest(TestCase):
         self.assertEqual(op.get_unit(self.us), 'm/s')
 
     def test_get_unit_dimensions(self):
-        Q_ = self.us.ureg.Quantity
+        q_ = self.us.ureg.Quantity
         op = Operand(
             name='toto',
             value=15,
             unit='[mass]/[time]'
         )
-        self.assertIsInstance(Q_(1, op.get_unit(self.us)), Q_)
+        self.assertIsInstance(q_(1, op.get_unit(self.us)), q_)
 
     def test_get_unit_mixed(self):
-        Q_ = self.us.ureg.Quantity
+        q_ = self.us.ureg.Quantity
         op = Operand(
             name='toto',
             value=15,
             unit='[mass]/[time]*L'
         )
-        self.assertIsInstance(Q_(1, op.get_unit(self.us)), Q_)
+        self.assertIsInstance(q_(1, op.get_unit(self.us)), q_)
 
-    def test_get_unit_mixed(self):
-        Q_ = self.us.ureg.Quantity
+    def test_get_unit_mixed_custom(self):
+        q_ = self.us.ureg.Quantity
         op = Operand(
             name='toto',
             value=15,
             unit='[mass]/[time]*L*plouf'
         )
-        self.assertRaises(pint.errors.UndefinedUnitError, Q_, 1, op.get_unit(self.us))
+        self.assertRaises(pint.errors.UndefinedUnitError, q_, 1, op.get_unit(self.us))
 
 
 class ExpressionAPITest(TestCase):
